@@ -218,10 +218,15 @@ typedef struct
 #define FEITIANR502DUAL 0x096E060D
 #define MICROCHIP_SEC1100 0x04241104
 #define CHERRY_KC1000SC 0x046A00A1
-#define ElatecTWN4	0x09D80427
+#define ElatecTWN4_CCID_CDC	0x09D80427
+#define ElatecTWN4_CCID	0x09D80428
 #define SCM_SCL011 0x04E65293
 #define HID_AVIATOR	0x076B3A21
 #define HID_OMNIKEY_5422 0x076B5422
+#define HID_OMNIKEY_3X21 0x076B3031 /* OMNIKEY 3121 or 3021 or 1021 */
+#define HID_OMNIKEY_6121 0x076B6632 /* OMNIKEY 6121 */
+#define CHERRY_XX44	0x046A00A7 /* Cherry Smart Terminal xx44 */
+#define FUJITSU_D323 0x0BF81024 /* Fujitsu Smartcard Reader D323 */
 
 #define VENDOR_GEMALTO 0x08E6
 #define GET_VENDOR(readerID) ((readerID >> 16) & 0xFFFF)
